@@ -1,14 +1,13 @@
 from .extension import FlaskSchema
-from .mixins import SchemaValidationError
 from .typing import ResponseReturnValue
-from .validation import DataSource, validate
+from .validation import DataSource, validate, tags
 from .command import generate_schema_command
 
 __all__ = (
     "DataSource",
     "FlaskSchema",
     "ResponseReturnValue",
-    "SchemaValidationError",
     "validate",
+    "tags",
     "generate_schema_command"
 )
